brick_rest library
Classes
- Rest
-
An annotation used to specify how a field is serialized for a
RestAdapter. Heavily inspired by JsonKey -
RestAdapter<
TModel extends RestModel> - Constructors that convert app models to and from REST
- RestModel
-
Models accessible to the
RestProvider - RestModelDictionary
- Associates app models with their RestAdapter
- RestProvider
- Retrieves from an HTTP endpoint
- RestProviderQuery
-
A REST-specific query definitiion for use in
Query. - RestRequest
-
A cohesive definition for
RestRequestTransformer's instance fields. - RestRequestTransformer
-
Specify request formatting (such as
methodorurl) for each Brick operation. - RestSerializable
- An annotation used to specify a class to generate code for.
Enums
- FieldRename
- Values for the automatic field renaming behavior for class-level serializables.
Exceptions / Errors
- RestException
- An error class exclusive to the RestProvider