RestModelDictionary class

Associates app models with their RestAdapter

Constructors

RestModelDictionary(Map<Type, RestAdapter<RestModel>> mappings)
const

Properties

adapterFor → Map<Type, RestAdapter<RestModel>>
A generated map associating models to adapters
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited